@@ -1,38 +1,27 @@
-from typing import Optional
-import os
-import sys
-import spacy
-
-
 from explainaboard.utils.spacy_loader import spacy_loader
-
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-from info import *
-from typing import Iterable
-from info import SysOutputInfo
-from info import BucketPerformance
-from info import Performance
-from info import Table
-from explainaboard.utils import analysis
-from explainaboard.utils.analysis import *
-from explainaboard.utils.eval_bucket import *
-from metric import Accuracy
-from metric import F1score
+from typing import Iterable, Optional
+from explainaboard.info import SysOutputInfo, BucketPerformance, Performance, Table
+from explainaboard.utils.analysis import *  # noqa
+from explainaboard.utils.eval_bucket import *  # noqa
+from explainaboard.metric import *  # noqa
 from tqdm import tqdm
 
 spacy_nlp = spacy_loader.get_model("en_core_web_sm")
 
+
 class ABSCExplainaboardBuilder:
     """
-        Input: System Output file List[dict];  Metadata info
-        Output: Analysis
+    Input: System Output file List[dict];  Metadata info
+    Output: Analysis
     """
 
-    def __init__(self, info: SysOutputInfo,
-                 system_output_object: Iterable[dict],
-                 feature_table: Optional[Table] = {},
-                 gen_kwargs: dict = None
-                 ):
+    def __init__(
+        self,
+        info: SysOutputInfo,
+        system_output_object: Iterable[dict],
+        feature_table: Optional[Table] = {},
+        gen_kwargs: dict = None,
+    ):
         self._info = info
         self._system_output: Iterable[dict] = system_output_object
         self.gen_kwargs = gen_kwargs
@@ -73,12 +62,16 @@ class ABSCExplainaboardBuilder:
         :return:
         """
         # Get names of bucketing features
-        #print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
+        # print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
+        for _id, dict_sysout in tqdm(
+            enumerate(self._system_output), desc="featurizing"
+        ):
             # Get values of bucketing features
             for bucket_feature in bucket_features:
-                feature_value = eval(ABSCExplainaboardBuilder.get_bucket_feature_value(bucket_feature))(dict_sysout)
+                feature_value = eval(
+                    ABSCExplainaboardBuilder.get_bucket_feature_value(bucket_feature)
+                )(dict_sysout)
                 dict_sysout[bucket_feature] = feature_value
             self._data[_id] = dict_sysout
             yield _id, dict_sysout
@@ -91,21 +84,23 @@ class ABSCExplainaboardBuilder:
             true_labels.append(feature_table["true_label"])
 
         for metric_name in self._info.metric_names:
-            one_metric = eval(metric_name)(true_labels=true_labels,
-                                           predicted_labels=predicted_labels,
-                                           is_print_confidence_interval=self._info.results.is_print_confidence_interval)
+            one_metric = eval(metric_name)(
+                true_labels=true_labels,
+                predicted_labels=predicted_labels,
+                is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+            )
             overall_value_json = one_metric.evaluate()
 
             overall_value = overall_value_json["value"]
             confidence_score_low = overall_value_json["confidence_score_low"]
             confidence_score_up = overall_value_json["confidence_score_up"]
             overall_performance = Performance(
-                                   metric_name=metric_name,
-                                   value=float(format(overall_value, '.4g')),
-                                   confidence_score_low=float(format(confidence_score_low, '.4g')),
-                                   confidence_score_up=float(format(confidence_score_up, '.4g')),
+                metric_name=metric_name,
+                value=float(format(overall_value, '.4g')),
+                confidence_score_low=float(format(confidence_score_low, '.4g')),
+                confidence_score_up=float(format(confidence_score_up, '.4g')),
             )
-            if self._info.results.overall == None:
+            if self._info.results.overall is None:
                 self._info.results.overall = {}
                 self._info.results.overall[metric_name] = overall_performance
             else:
@@ -124,24 +119,33 @@ class ABSCExplainaboardBuilder:
                 if feature_name not in feature_to_sample_address_to_value.keys():
                     feature_to_sample_address_to_value[feature_name] = {}
                 else:
-                    feature_to_sample_address_to_value[feature_name][sample_address] = dict_sysout[feature_name]
+                    feature_to_sample_address_to_value[feature_name][
+                        sample_address
+                    ] = dict_sysout[feature_name]
 
         # Bucketing
-        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
+        for feature_name in tqdm(
+            self._info.features.get_bucket_features(), desc="bucketing"
+        ):
             # print(f"Feature Name: {feature_name}\n"
             #       f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
             #       f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
             #       f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
 
-            self._samples_over_bucket[feature_name] = eval(self._info.features[feature_name].bucket_info._method)(
+            self._samples_over_bucket[feature_name] = eval(
+                self._info.features[feature_name].bucket_info._method
+            )(
                 dict_obj=feature_to_sample_address_to_value[feature_name],
                 bucket_number=self._info.features[feature_name].bucket_info._number,
-                bucket_setting=self._info.features[feature_name].bucket_info._setting)
+                bucket_setting=self._info.features[feature_name].bucket_info._setting,
+            )
 
             # print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
 
             # evaluating bucket: get bucket performance
-            self._performances_over_bucket[feature_name] = self.get_bucket_performance(feature_name)
+            self._performances_over_bucket[feature_name] = self.get_bucket_performance(
+                feature_name
+            )
 
     def get_bucket_performance(self, feature_name: str):
         """
@@ -151,7 +155,9 @@ class ABSCExplainaboardBuilder:
         """
 
         bucket_name_to_performance = {}
-        for bucket_interval, sample_ids in self._samples_over_bucket[feature_name].items():
+        for bucket_interval, sample_ids in self._samples_over_bucket[
+            feature_name
+        ].items():
 
             bucket_true_labels = []
             bucket_predicted_labels = []
@@ -161,7 +167,7 @@ class ABSCExplainaboardBuilder:
 
                 true_label = self._data[int(sample_id)]["true_label"]
                 predicted_label = self._data[int(sample_id)]["predicted_label"]
-                sent = self._data[int(sample_id)]["text"]
+                sent = self._data[int(sample_id)]["text"]  # noqa
                 s_id = self._data[int(sample_id)]["id"]
 
                 # get a bucket of true/predicted labels
@@ -175,9 +181,11 @@ class ABSCExplainaboardBuilder:
 
             bucket_name_to_performance[bucket_interval] = []
             for metric_name in self._info.metric_names:
-                one_metric = eval(metric_name)(true_labels=bucket_true_labels,
-                                               predicted_labels=bucket_predicted_labels,
-                                               is_print_confidence_interval=self._info.results.is_print_confidence_interval)
+                one_metric = eval(metric_name)(
+                    true_labels=bucket_true_labels,
+                    predicted_labels=bucket_predicted_labels,
+                    is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+                )
                 bucket_value_json = one_metric.evaluate()
 
                 bucket_value = bucket_value_json["value"]
@@ -190,24 +198,26 @@ class ABSCExplainaboardBuilder:
                 #       f"confidence up \t {confidence_score_up}\n"
                 #       f"---------------------------------")
 
-                bucket_performance = BucketPerformance(bucket_name=bucket_interval,
-                                                       metric_name=metric_name,
-                                                       value=format(bucket_value, '.4g'),
-                                                       confidence_score_low=format(confidence_score_low, '.4g'),
-                                                       confidence_score_up=format(confidence_score_up, '.4g'),
-                                                       n_samples=len(bucket_true_labels),
-                                                       bucket_samples=bucket_cases)
+                bucket_performance = BucketPerformance(
+                    bucket_name=bucket_interval,
+                    metric_name=metric_name,
+                    value=format(bucket_value, '.4g'),
+                    confidence_score_low=format(confidence_score_low, '.4g'),
+                    confidence_score_up=format(confidence_score_up, '.4g'),
+                    n_samples=len(bucket_true_labels),
+                    bucket_samples=bucket_cases,
+                )
 
                 bucket_name_to_performance[bucket_interval].append(bucket_performance)
 
-        return sort_dict(bucket_name_to_performance)
+        return sort_dict(bucket_name_to_performance)  # noqa
 
     def _generate_report(self):
         dict_fine_grained = {}
         for feature_name, metadata in self._performances_over_bucket.items():
             dict_fine_grained[feature_name] = []
             for bucket_name, bucket_performance in metadata.items():
-                bucket_name = analysis.beautify_interval(bucket_name)
+                bucket_name = beautify_interval(bucket_name)  # noqa
 
                 # instantiation
                 dict_fine_grained[feature_name].append(bucket_performance)
@@ -216,7 +226,9 @@ class ABSCExplainaboardBuilder:
 
     def _print_bucket_info(self):
         for feature_name in self._performances_over_bucket.keys():
-            print_dict(self._performances_over_bucket[feature_name], feature_name)
+            print_dict(  # noqa
+                self._performances_over_bucket[feature_name], feature_name
+            )
 
     def run(self) -> SysOutputInfo:
         eb_generator = self._complete_feature()
