@@ -1,19 +1,12 @@
-from typing import Optional, Iterable
+from typing import Iterable, Optional
 from explainaboard.info import SysOutputInfo, BucketPerformance, Performance, Table
 from explainaboard.utils import analysis
-from explainaboard.utils.analysis import *
-from explainaboard.utils.eval_bucket import *
-from metric import Accuracy
-from metric import F1score
-from metric import Hits
+from explainaboard.utils.eval_bucket import *  # noqa
+from explainaboard.utils.analysis import *  # noqa
+from explainaboard.metric import *  # noqa
 from tqdm import tqdm
-from explainaboard.utils.feature_funcs import *
-from explainaboard.utils.spacy_loader import spacy_loader
 from datalabs import load_dataset
-
-from aggregate import *
-
-
+from datalabs.operations import aggregate
 
 
 class KGLTPExplainaboardBuilder:
@@ -22,11 +15,13 @@ class KGLTPExplainaboardBuilder:
     Output: Analysis
     """
 
-    def __init__(self, info: SysOutputInfo,
-                 system_output_object: Iterable[dict],
-                 feature_table: Optional[Table] = {},
-                 gen_kwargs:dict = None
-                 ):
+    def __init__(
+        self,
+        info: SysOutputInfo,
+        system_output_object: Iterable[dict],
+        feature_table: Optional[Table] = {},
+        gen_kwargs: dict = None,
+    ):
         self._info = info
         self._system_output: Iterable[dict] = system_output_object
         self.gen_kwargs = gen_kwargs
@@ -37,54 +32,55 @@ class KGLTPExplainaboardBuilder:
         # _performances_over_bucket: performance in different bucket: Dict(feature_name, bucket_name, performance)
         self._performances_over_bucket = {}
 
-
-        if self._info.dataset_name != "fb15k_237": # to be generalized
+        if self._info.dataset_name != "fb15k_237":  # to be generalized
             self.statistics = None
         else:
             dataset = load_dataset(self._info.dataset_name, 'readable')
-            new_train = dataset['train'].apply(get_statistics)
+            new_train = dataset['train'].apply(aggregate.get_statistics)
             self.statistics = new_train._stat
 
-
-
     @staticmethod
-    def get_bucket_feature_value(feature_name:str):
+    def get_bucket_feature_value(feature_name: str):
         return "self._get_" + feature_name
 
     # define function for incomplete features
     def _get_tail_entity_length(self, existing_features: dict):
         return len(existing_features["true_tail"].split(" "))
 
-
     # define function for incomplete features
     def _get_head_entity_length(self, existing_features: dict):
         return len(existing_features["true_head"].split(" "))
 
-
     # define function for incomplete features
     def _get_tail_fre(self, existing_features: dict):
-        if self.statistics is None or existing_features["true_tail"] not in self.statistics['tail_fre'].keys():
+        if (
+            self.statistics is None
+            or existing_features["true_tail"] not in self.statistics['tail_fre'].keys()
+        ):
             return 0
         else:
             return self.statistics['tail_fre'][existing_features["true_tail"]]
 
     # define function for incomplete features
     def _get_head_fre(self, existing_features: dict):
-        if self.statistics is None or existing_features["true_head"] not in self.statistics['head_fre'].keys():
+        if (
+            self.statistics is None
+            or existing_features["true_head"] not in self.statistics['head_fre'].keys()
+        ):
             return 0
         else:
             return self.statistics['head_fre'][existing_features["true_head"]]
 
     # define function for incomplete features
     def _get_link_fre(self, existing_features: dict):
-        if self.statistics is None or existing_features["link"] not in self.statistics['link_fre'].keys():
+        if (
+            self.statistics is None
+            or existing_features["link"] not in self.statistics['link_fre'].keys()
+        ):
             return 0
         else:
             return self.statistics['link_fre'][existing_features["link"]]
 
-
-
-
     def _complete_feature(self):
         """
         This function is used to calculate features used for bucekting, such as sentence_length
@@ -92,47 +88,49 @@ class KGLTPExplainaboardBuilder:
         :return:
         """
         # Get names of bucketing features
-        #print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
+        # print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
+        for _id, dict_sysout in tqdm(
+            enumerate(self._system_output), desc="featurizing"
+        ):
             # Get values of bucketing features
             for bucket_feature in bucket_features:
-                feature_value = eval(KGLTPExplainaboardBuilder.get_bucket_feature_value(bucket_feature))(dict_sysout)
+                feature_value = eval(
+                    KGLTPExplainaboardBuilder.get_bucket_feature_value(bucket_feature)
+                )(dict_sysout)
                 dict_sysout[bucket_feature] = feature_value
-            # if self._data == None:
+            # if self._data is None:
             #     self._data = {}
             self._data[_id] = dict_sysout
             yield _id, dict_sysout
 
     def get_overall_performance(self):
-        predicted_labels,true_labels = [], []
+        predicted_labels, true_labels = [], []
 
         for _id, feature_table in self._data.items():
 
             predicted_labels.append(feature_table["predicted_tails"])
             true_labels.append(feature_table["true_tail"])
 
-
-
         for metric_name in self._info.metric_names:
-            one_metric = eval(metric_name)(true_labels = true_labels,
-                                           predicted_labels = predicted_labels,
-                                           is_print_confidence_interval = self._info.results.is_print_confidence_interval)
+            one_metric = eval(metric_name)(
+                true_labels=true_labels,
+                predicted_labels=predicted_labels,
+                is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+            )
             overall_value_json = one_metric.evaluate()
 
-
-
             overall_value = overall_value_json["value"]
             confidence_score_low = overall_value_json["confidence_score_low"]
             confidence_score_up = overall_value_json["confidence_score_up"]
             overall_performance = Performance(
-                                                   metric_name=metric_name,
-                                                   value=float(format(overall_value, '.4g')),
-                                                   confidence_score_low=float(format(confidence_score_low, '.4g')),
-                                                   confidence_score_up=float(format(confidence_score_up, '.4g')),
+                metric_name=metric_name,
+                value=float(format(overall_value, '.4g')),
+                confidence_score_low=float(format(confidence_score_low, '.4g')),
+                confidence_score_up=float(format(confidence_score_up, '.4g')),
             )
 
-            if self._info.results.overall == None:
+            if self._info.results.overall is None:
                 self._info.results.overall = {}
                 self._info.results.overall[metric_name] = overall_performance
             else:
@@ -140,39 +138,47 @@ class KGLTPExplainaboardBuilder:
 
     def _bucketing_samples(self, sysout_iterator):
 
-        sample_address= ""
+        sample_address = ""
         feature_to_sample_address_to_value = {}
 
-
         # Preparation for bucketing
         for _id, dict_sysout in sysout_iterator:
 
-            sample_address = str(_id) # this could be abstracted later
+            sample_address = str(_id)  # this could be abstracted later
             for feature_name in self._info.features.get_bucket_features():
                 if feature_name not in feature_to_sample_address_to_value.keys():
                     feature_to_sample_address_to_value[feature_name] = {}
                 else:
-                    feature_to_sample_address_to_value[feature_name][sample_address] = dict_sysout[feature_name]
+                    feature_to_sample_address_to_value[feature_name][
+                        sample_address
+                    ] = dict_sysout[feature_name]
 
         # Bucketing
-        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
+        for feature_name in tqdm(
+            self._info.features.get_bucket_features(), desc="bucketing"
+        ):
 
             # print(f"Feature Name: {feature_name}\n"
             #       f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
             #       f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
             #       f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
 
-            self._samples_over_bucket[feature_name] = eval(self._info.features[feature_name].bucket_info._method)(
-                                dict_obj = feature_to_sample_address_to_value[feature_name],
-                                bucket_number = self._info.features[feature_name].bucket_info._number,
-                                bucket_setting = self._info.features[feature_name].bucket_info._setting)
+            self._samples_over_bucket[feature_name] = eval(
+                self._info.features[feature_name].bucket_info._method
+            )(
+                dict_obj=feature_to_sample_address_to_value[feature_name],
+                bucket_number=self._info.features[feature_name].bucket_info._number,
+                bucket_setting=self._info.features[feature_name].bucket_info._setting,
+            )
 
             # print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
 
             # evaluating bucket: get bucket performance
-            self._performances_over_bucket[feature_name] = self.get_bucket_performance(feature_name)
+            self._performances_over_bucket[feature_name] = self.get_bucket_performance(
+                feature_name
+            )
 
-    def get_bucket_performance(self, feature_name:str):
+    def get_bucket_performance(self, feature_name: str):
         """
         This function defines how to get bucket-level performance w.r.t a given feature (e.g., sentence length)
         :param feature_name: the name of a feature, e.g., sentence length
@@ -180,18 +186,19 @@ class KGLTPExplainaboardBuilder:
         """
 
         bucket_name_to_performance = {}
-        for bucket_interval, sample_ids in self._samples_over_bucket[feature_name].items():
+        for bucket_interval, sample_ids in self._samples_over_bucket[
+            feature_name
+        ].items():
 
-            bucket_true_labels      = []
-            bucket_predicted_labels = [] #  list of (lists of top-k ranked tails) 
+            bucket_true_labels = []
+            bucket_predicted_labels = []  # list of (lists of top-k ranked tails)
             bucket_cases = []
 
-
             for sample_id in sample_ids:
 
                 true_label = self._data[int(sample_id)]["true_tail"]
                 predicted_label = self._data[int(sample_id)]["predicted_tails"]
-                sent = self._data[int(sample_id)]["link"]
+                sent = self._data[int(sample_id)]["link"]  # noqa
                 s_id = self._data[int(sample_id)]["id"]
 
                 # get a bucket of true/predicted labels
@@ -200,7 +207,7 @@ class KGLTPExplainaboardBuilder:
                 # get a bucket of cases (e.g., errors)
                 if self._info.results.is_print_case:
                     if true_label not in predicted_label:
-                        #bucket_case = true_label + "|||" + predicted_label + "|||" + sent
+                        # bucket_case = true_label + "|||" + predicted_label + "|||" + sent
                         # bucket_case = {"true_label":(s_id,["true_label"]),
                         #                "predicted_label":(s_id,["predicted_label"]),
                         #                "text":(s_id,["text"])}
@@ -210,13 +217,13 @@ class KGLTPExplainaboardBuilder:
             bucket_name_to_performance[bucket_interval] = []
             for metric_name in self._info.metric_names:
 
-                one_metric = eval(metric_name)(true_labels = bucket_true_labels,
-                                           predicted_labels = bucket_predicted_labels,
-                                           is_print_confidence_interval = self._info.results.is_print_confidence_interval)
+                one_metric = eval(metric_name)(
+                    true_labels=bucket_true_labels,
+                    predicted_labels=bucket_predicted_labels,
+                    is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+                )
                 bucket_value_json = one_metric.evaluate()
 
-
-
                 bucket_value = bucket_value_json["value"]
                 confidence_score_low = bucket_value_json["confidence_score_low"]
                 confidence_score_up = bucket_value_json["confidence_score_up"]
@@ -227,21 +234,19 @@ class KGLTPExplainaboardBuilder:
                 #       f"confidence up \t {confidence_score_up}\n"
                 #       f"---------------------------------")
 
-                bucket_performance = BucketPerformance(bucket_name=bucket_interval,
-                                  metric_name = metric_name,
-                                  value = format(bucket_value, '.4g'),
-                                  confidence_score_low = format(confidence_score_low, '.4g'),
-                                  confidence_score_up = format(confidence_score_up, '.4g'),
-                                  n_samples = len(bucket_true_labels),
-                                  bucket_samples=bucket_cases)
+                bucket_performance = BucketPerformance(
+                    bucket_name=bucket_interval,
+                    metric_name=metric_name,
+                    value=format(bucket_value, '.4g'),
+                    confidence_score_low=format(confidence_score_low, '.4g'),
+                    confidence_score_up=format(confidence_score_up, '.4g'),
+                    n_samples=len(bucket_true_labels),
+                    bucket_samples=bucket_cases,
+                )
 
                 bucket_name_to_performance[bucket_interval].append(bucket_performance)
 
-
-
-
-        return sort_dict(bucket_name_to_performance)
-
+        return sort_dict(bucket_name_to_performance)  # noqa
 
     def _generate_report(self):
         dict_fine_grained = {}
@@ -257,9 +262,9 @@ class KGLTPExplainaboardBuilder:
 
     def _print_bucket_info(self):
         for feature_name in self._performances_over_bucket.keys():
-            print_dict(self._performances_over_bucket[feature_name], feature_name)
-
-
+            print_dict(  # noqa
+                self._performances_over_bucket[feature_name], feature_name
+            )
 
     def run(self) -> SysOutputInfo:
         eb_generator = self._complete_feature()
@@ -268,6 +273,3 @@ class KGLTPExplainaboardBuilder:
         self._print_bucket_info()
         self._generate_report()
         return self._info
-
-
-
