@@ -1,12 +1,12 @@
 from typing import Optional, Iterable
 from explainaboard.info import SysOutputInfo, BucketPerformance, Performance, Table
 from explainaboard.utils import analysis
-from explainaboard.utils.analysis import *
-from explainaboard.utils.eval_bucket import *
-from explainaboard.metric import Accuracy
-from explainaboard.metric import F1score
+from explainaboard.utils.analysis import *  # noqa
+from explainaboard.utils.eval_bucket import *  # noqa
+from explainaboard.metric import Accuracy  # noqa
+from explainaboard.metric import F1score  # noqa
 from tqdm import tqdm
-from explainaboard.utils.feature_funcs import *
+from explainaboard.utils.feature_funcs import *  # noqa
 from explainaboard.utils.spacy_loader import spacy_loader
 
 
@@ -16,11 +16,13 @@ class TCExplainaboardBuilder:
     Output: Analysis
     """
 
-    def __init__(self, info: SysOutputInfo,
-                 system_output_object: Iterable[dict],
-                 feature_table: Optional[Table] = {},
-                 gen_kwargs:dict = None
-                 ):
+    def __init__(
+        self,
+        info: SysOutputInfo,
+        system_output_object: Iterable[dict],
+        feature_table: Optional[Table] = {},
+        gen_kwargs: dict = None,
+    ):
         self._info = info
         self._system_output: Iterable[dict] = system_output_object
         self.gen_kwargs = gen_kwargs
@@ -43,10 +45,8 @@ class TCExplainaboardBuilder:
     #             sentence, true_label, predicted_label= line.split("\t")
     #             yield id_, {"sentence": sentence.strip(), "true_label": true_label.strip(), "predicted_label": predicted_label.strip()}
 
-
-
     @staticmethod
-    def get_bucket_feature_value(feature_name:str):
+    def get_bucket_feature_value(feature_name: str):
         return "self._get_" + feature_name
 
     # define function for incomplete features
@@ -57,17 +57,18 @@ class TCExplainaboardBuilder:
         return len(existing_feature["text"])
 
     def _get_entity_number(self, existing_feature: dict):
-        return len(spacy_loader.get_model("en_core_web_sm")(existing_feature["text"]).ents)
-    
+        return len(
+            spacy_loader.get_model("en_core_web_sm")(existing_feature["text"]).ents
+        )
+
     def _get_label(self, existing_feature: dict):
         return existing_feature["true_label"]
 
     def _get_basic_words(self, existing_feature: dict):
-        return get_basic_words(existing_feature["text"])
+        return get_basic_words(existing_feature["text"])  # noqa
 
     def _get_lexical_richness(self, existing_feature: dict):
-        return get_lexical_richness(existing_feature["text"])
-
+        return get_lexical_richness(existing_feature["text"])  # noqa
 
     def _complete_feature(self):
         """
@@ -76,47 +77,49 @@ class TCExplainaboardBuilder:
         :return:
         """
         # Get names of bucketing features
-        #print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
+        # print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
+        for _id, dict_sysout in tqdm(
+            enumerate(self._system_output), desc="featurizing"
+        ):
             # Get values of bucketing features
             for bucket_feature in bucket_features:
-                feature_value = eval(TCExplainaboardBuilder.get_bucket_feature_value(bucket_feature))(dict_sysout)
+                feature_value = eval(
+                    TCExplainaboardBuilder.get_bucket_feature_value(bucket_feature)
+                )(dict_sysout)
                 dict_sysout[bucket_feature] = feature_value
-            # if self._data == None:
+            # if self._data is None:
             #     self._data = {}
             self._data[_id] = dict_sysout
             yield _id, dict_sysout
 
     def get_overall_performance(self):
-        predicted_labels,true_labels = [], []
+        predicted_labels, true_labels = [], []
 
         for _id, feature_table in self._data.items():
 
             predicted_labels.append(feature_table["predicted_label"])
             true_labels.append(feature_table["true_label"])
 
-
-
         for metric_name in self._info.metric_names:
-            one_metric = eval(metric_name)(true_labels = true_labels,
-                                           predicted_labels = predicted_labels,
-                                           is_print_confidence_interval = self._info.results.is_print_confidence_interval)
+            one_metric = eval(metric_name)(
+                true_labels=true_labels,
+                predicted_labels=predicted_labels,
+                is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+            )
             overall_value_json = one_metric.evaluate()
 
-
-
             overall_value = overall_value_json["value"]
             confidence_score_low = overall_value_json["confidence_score_low"]
             confidence_score_up = overall_value_json["confidence_score_up"]
             overall_performance = Performance(
-                                                   metric_name=metric_name,
-                                                   value=float(format(overall_value, '.4g')),
-                                                   confidence_score_low=float(format(confidence_score_low, '.4g')),
-                                                   confidence_score_up=float(format(confidence_score_up, '.4g'))
+                metric_name=metric_name,
+                value=float(format(overall_value, '.4g')),
+                confidence_score_low=float(format(confidence_score_low, '.4g')),
+                confidence_score_up=float(format(confidence_score_up, '.4g')),
             )
 
-            if self._info.results.overall == None:
+            if self._info.results.overall is None:
                 self._info.results.overall = {}
                 self._info.results.overall[metric_name] = overall_performance
             else:
@@ -124,39 +127,47 @@ class TCExplainaboardBuilder:
 
     def _bucketing_samples(self, sysout_iterator):
 
-        sample_address= ""
+        sample_address = ""
         feature_to_sample_address_to_value = {}
 
-
         # Preparation for bucketing
         for _id, dict_sysout in sysout_iterator:
 
-            sample_address = str(_id) # this could be abstracted later
+            sample_address = str(_id)  # this could be abstracted later
             for feature_name in self._info.features.get_bucket_features():
                 if feature_name not in feature_to_sample_address_to_value.keys():
                     feature_to_sample_address_to_value[feature_name] = {}
                 else:
-                    feature_to_sample_address_to_value[feature_name][sample_address] = dict_sysout[feature_name]
+                    feature_to_sample_address_to_value[feature_name][
+                        sample_address
+                    ] = dict_sysout[feature_name]
 
         # Bucketing
-        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
+        for feature_name in tqdm(
+            self._info.features.get_bucket_features(), desc="bucketing"
+        ):
 
             # print(f"Feature Name: {feature_name}\n"
             #       f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
             #       f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
             #       f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
 
-            self._samples_over_bucket[feature_name] = eval(self._info.features[feature_name].bucket_info._method)(
-                                dict_obj = feature_to_sample_address_to_value[feature_name],
-                                bucket_number = self._info.features[feature_name].bucket_info._number,
-                                bucket_setting = self._info.features[feature_name].bucket_info._setting)
+            self._samples_over_bucket[feature_name] = eval(
+                self._info.features[feature_name].bucket_info._method
+            )(
+                dict_obj=feature_to_sample_address_to_value[feature_name],
+                bucket_number=self._info.features[feature_name].bucket_info._number,
+                bucket_setting=self._info.features[feature_name].bucket_info._setting,
+            )
 
             # print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
 
             # evaluating bucket: get bucket performance
-            self._performances_over_bucket[feature_name] = self.get_bucket_performance(feature_name)
+            self._performances_over_bucket[feature_name] = self.get_bucket_performance(
+                feature_name
+            )
 
-    def get_bucket_performance(self, feature_name:str):
+    def get_bucket_performance(self, feature_name: str):
         """
         This function defines how to get bucket-level performance w.r.t a given feature (e.g., sentence length)
         :param feature_name: the name of a feature, e.g., sentence length
@@ -164,18 +175,19 @@ class TCExplainaboardBuilder:
         """
 
         bucket_name_to_performance = {}
-        for bucket_interval, sample_ids in self._samples_over_bucket[feature_name].items():
+        for bucket_interval, sample_ids in self._samples_over_bucket[
+            feature_name
+        ].items():
 
-            bucket_true_labels      = []
+            bucket_true_labels = []
             bucket_predicted_labels = []
             bucket_cases = []
 
-
             for sample_id in sample_ids:
 
                 true_label = self._data[int(sample_id)]["true_label"]
                 predicted_label = self._data[int(sample_id)]["predicted_label"]
-                sent = self._data[int(sample_id)]["text"]
+                sent = self._data[int(sample_id)]["text"]  # noqa
                 s_id = self._data[int(sample_id)]["id"]
 
                 # get a bucket of true/predicted labels
@@ -184,7 +196,7 @@ class TCExplainaboardBuilder:
                 # get a bucket of cases (e.g., errors)
                 if self._info.results.is_print_case:
                     if true_label != predicted_label:
-                        #bucket_case = true_label + "|||" + predicted_label + "|||" + sent
+                        # bucket_case = true_label + "|||" + predicted_label + "|||" + sent
                         # bucket_case = {"true_label":(s_id,["true_label"]),
                         #                "predicted_label":(s_id,["predicted_label"]),
                         #                "text":(s_id,["text"])}
@@ -194,13 +206,13 @@ class TCExplainaboardBuilder:
             bucket_name_to_performance[bucket_interval] = []
             for metric_name in self._info.metric_names:
 
-                one_metric = eval(metric_name)(true_labels = bucket_true_labels,
-                                           predicted_labels = bucket_predicted_labels,
-                                           is_print_confidence_interval = self._info.results.is_print_confidence_interval)
+                one_metric = eval(metric_name)(
+                    true_labels=bucket_true_labels,
+                    predicted_labels=bucket_predicted_labels,
+                    is_print_confidence_interval=self._info.results.is_print_confidence_interval,
+                )
                 bucket_value_json = one_metric.evaluate()
 
-
-
                 bucket_value = bucket_value_json["value"]
                 confidence_score_low = bucket_value_json["confidence_score_low"]
                 confidence_score_up = bucket_value_json["confidence_score_up"]
@@ -211,21 +223,19 @@ class TCExplainaboardBuilder:
                 #       f"confidence up \t {confidence_score_up}\n"
                 #       f"---------------------------------")
 
-                bucket_performance = BucketPerformance(bucket_name=bucket_interval,
-                                  metric_name = metric_name,
-                                  value = format(bucket_value, '.4g'),
-                                  confidence_score_low = format(confidence_score_low, '.4g'),
-                                  confidence_score_up = format(confidence_score_up, '.4g'),
-                                  n_samples = len(bucket_true_labels),
-                                  bucket_samples=bucket_cases)
+                bucket_performance = BucketPerformance(
+                    bucket_name=bucket_interval,
+                    metric_name=metric_name,
+                    value=format(bucket_value, '.4g'),
+                    confidence_score_low=format(confidence_score_low, '.4g'),
+                    confidence_score_up=format(confidence_score_up, '.4g'),
+                    n_samples=len(bucket_true_labels),
+                    bucket_samples=bucket_cases,
+                )
 
                 bucket_name_to_performance[bucket_interval].append(bucket_performance)
 
-
-
-
-        return sort_dict(bucket_name_to_performance)
-
+        return sort_dict(bucket_name_to_performance)  # noqa
 
     def _generate_report(self):
         dict_fine_grained = {}
@@ -241,9 +251,9 @@ class TCExplainaboardBuilder:
 
     def _print_bucket_info(self):
         for feature_name in self._performances_over_bucket.keys():
-            print_dict(self._performances_over_bucket[feature_name], feature_name)
-
-
+            print_dict(  # noqa
+                self._performances_over_bucket[feature_name], feature_name
+            )
 
     def run(self) -> SysOutputInfo:
         eb_generator = self._complete_feature()
@@ -252,6 +262,3 @@ class TCExplainaboardBuilder:
         self._print_bucket_info()
         self._generate_report()
         return self._info
-
-
-
