@@ -1,11 +1,11 @@
 from typing import Dict, Iterable, List
-from explainaboard.constants import *
+from explainaboard.constants import Source, FileType
+from enum import Enum
 from explainaboard.tasks import TaskType
 from .loader import register_loader
 from .loader import Loader
 
 
-
 @register_loader(TaskType.kg_link_tail_prediction)
 class KgLinkTailPredictionLoader(Loader):
     """
@@ -16,19 +16,17 @@ class KgLinkTailPredictionLoader(Loader):
         please refer to `test_loaders.py`
     """
 
-    def __init__(self, source: Source, file_type: Enum, data :str = None):
+    def __init__(self, source: Source, file_type: Enum, data: str = None):
 
-        if source == None:
+        if source is None:
             source = Source.local_filesystem
-        if file_type == None:
+        if file_type is None:
             file_type = FileType.json
 
-
         self._source = source
         self._file_type = file_type
         self._data = data
 
-
     def load(self) -> Iterable[Dict]:
         """
         :param path_system_output: the path of system output file with following format:
@@ -36,17 +34,19 @@ class KgLinkTailPredictionLoader(Loader):
 
         :return: class object
         """
-        raw_data = self._load_raw_data_points() # for json files: loads the entire json
+        raw_data = self._load_raw_data_points()  # for json files: loads the entire json
         data: List[Dict] = []
         if self._file_type == FileType.json:
             for id, (link, predictions) in enumerate(raw_data.items()):
-                data.append({
-                    "id": str(id), # should be string type
-                    "link": link.strip(),
-                    "true_head": link.split('\t')[0].strip(),
-                    "true_tail": link.split('\t')[-1].strip(),
-                    "predicted_tails": predictions
-                })
+                data.append(
+                    {
+                        "id": str(id),  # should be string type
+                        "link": link.strip(),
+                        "true_head": link.split('\t')[0].strip(),
+                        "true_tail": link.split('\t')[-1].strip(),
+                        "predicted_tails": predictions,
+                    }
+                )
         else:
             raise NotImplementedError
         return data
