@@ -1,8 +1,9 @@
+# flake8: noqa
 # when a new processor is implemented, remember to import it here so it gets registered
 from . import text_classification
 from . import named_entity_recognition
-from . import extractive_qa
-from . import summarization
+from . import extractive_qa_squad
+from . import conditional_generation
 
 from . import text_pair_classification
 from . import hellaswag
@@ -10,5 +11,5 @@ from . import hellaswag
 from . import aspect_based_sentiment_classification
 
 from . import kg_link_tail_prediction
-
-from .processor_registry import get_processor
\ No newline at end of file
+from . import qa_multiple_choice
+from .processor_registry import get_processor
