@@ -6,7 +6,9 @@ from explainaboard.processors.processor import Processor
 _processor_registry: dict = {}
 
 
-def get_processor(task: TaskType, metadata: dict = None, data: Iterable[dict] = None) -> Processor:
+def get_processor(
+    task: TaskType, metadata: dict = None, data: Iterable[dict] = None
+) -> Processor:
     """
     return a processor based on the task type
     TODO: error handling
@@ -16,10 +18,12 @@ def get_processor(task: TaskType, metadata: dict = None, data: Iterable[dict] =
 
 def register_processor(task_type: TaskType):
     """
-    a register for task specific processors. 
+    a register for task specific processors.
     example usage: `@register_processor(TaskType.text_classification)`
     """
+
     def register_processor_fn(cls):
         _processor_registry[task_type] = cls
         return cls
+
     return register_processor_fn
