@@ -4,22 +4,29 @@ import unittest
 from explainaboard import FileType, Source, TaskType, get_loader, get_processor
 
 artifacts_path = os.path.dirname(pathlib.Path(__file__)) + "/artifacts/"
-class TestKgLinkTailPrediction(unittest.TestCase):
 
-    
+
+class TestKgLinkTailPrediction(unittest.TestCase):
     def test_generate_system_analysis(self):
-        
+
         path_data = artifacts_path + "test-kg-link-tail-prediction.json"
-        loader = get_loader(TaskType.kg_link_tail_prediction, Source.local_filesystem, FileType.json, path_data)
+        loader = get_loader(
+            TaskType.kg_link_tail_prediction,
+            Source.local_filesystem,
+            FileType.json,
+            path_data,
+        )
         data = loader.load()
 
         metadata = {
             "task_name": TaskType.kg_link_tail_prediction.value,
             "dataset_name": "fb15k-237",
-            "metric_names": ["Hits"]
+            "metric_names": ["Hits"],
         }
-        
-        processor = get_processor(TaskType.kg_link_tail_prediction.value, metadata, data)
+
+        processor = get_processor(
+            TaskType.kg_link_tail_prediction.value, metadata, data
+        )
 
         analysis = processor.process()
 
@@ -30,4 +37,4 @@ class TestKgLinkTailPrediction(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
