@@ -1,28 +1,32 @@
 import pathlib
 import os
 import unittest
-from explainaboard.tasks import TaskType
 from explainaboard import FileType, Source, TaskType, get_loader, get_processor
 
 artifacts_path = os.path.dirname(pathlib.Path(__file__)) + "/artifacts/"
-class TestSummarization(unittest.TestCase):
 
+
+class TestSummarization(unittest.TestCase):
     def test_generate_system_analysis(self):
         """TODO: should add harder tests"""
 
-        path_data = artifacts_path+ "test-summ.tsv"
-        loader = get_loader(TaskType.summarization, Source.local_filesystem, FileType.tsv, path_data)
+        path_data = artifacts_path + "test-summ.tsv"
+        loader = get_loader(
+            TaskType.summarization, Source.local_filesystem, FileType.tsv, path_data
+        )
         data = loader.load()
 
-        metadata = {"task_name": TaskType.summarization.value,
-                    "dataset_name":"cnndm",
-                    "metric_names": ["bleu"]}
+        metadata = {
+            "task_name": TaskType.summarization.value,
+            "dataset_name": "cnndm",
+            "metric_names": ["bleu"],
+        }
 
         processor = get_processor(TaskType.summarization.value, metadata, data)
-        #self.assertEqual(len(processor._features), 4)
+        # self.assertEqual(len(processor._features), 4)
 
         analysis = processor.process()
-        analysis.write_to_directory("./")
+        # analysis.write_to_directory("./")
         # print(analysis)
         self.assertListEqual(analysis.metric_names, metadata["metric_names"])
         self.assertIsNotNone(analysis.results.fine_grained)
@@ -30,4 +34,4 @@ class TestSummarization(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
